@@ -3,10 +3,16 @@ import os
 import platform
 import shutil
 import stat
-from contextlib import suppress
 from pathlib import Path
 from typing import Union
 
+try:
+    from typing import Protocol
+except ImportError:
+    Protocol = object
+
+from .interface import PathOrStr
+
 if platform.system() == 'Windows':
     def rmtree(path, ignore_errors=False):
         # source: https://docs.python.org/3.10/library/shutil.html#rmtree-example
@@ -16,8 +22,22 @@ if platform.system() == 'Windows':
 
         shutil.rmtree(path, ignore_errors=ignore_errors, onerror=remove_readonly)
 
+
+    def get_path_group(path: PathOrStr) -> Union[int, None]:
+        pass
+
+
+    def remove_file(path: PathOrStr):
+        os.chmod(path, stat.S_IWRITE)
+        os.remove(path)
+
 else:
     rmtree = shutil.rmtree
+    remove_file = os.remove
+
+
+    def get_path_group(path: PathOrStr) -> Union[int, None]:
+        return Path(path).stat().st_gid
 
 
 def set_path_attrs(path: Path, permissions: Union[int, None] = None, group: Union[str, int, None] = None):
@@ -27,14 +47,7 @@ def set_path_attrs(path: Path, permissions: Union[int, None] = None, group: Unio
         shutil.chown(path, group=group)
 
 
-def get_path_group(path: Path):
-    with suppress(NotImplementedError):
-        # this will trigger an error on windows
-        path.group()
-        return path.stat().st_gid
-
-
-def copy_file(source, destination):
+def copy_file(source: PathOrStr, destination: PathOrStr):
     # in Python>=3.8 the sendfile call is used, which apparently may fail
     try:
         shutil.copyfile(source, destination)
@@ -45,3 +58,13 @@ def copy_file(source, destination):
 
         with open(source, 'rb') as src, open(destination, 'wb') as dst:
             shutil.copyfileobj(src, dst)
+
+
+class HashAlgorithm(Protocol):
+    digest_size: int
+
+    def update(self, chunk: bytes) -> None:
+        pass
+
+    def digest(self) -> bytes:
+        pass
