@@ -1,7 +1,5 @@
 class StorageCorruption(OSError):
-    """
-    Denotes various problems with disk-based storage or persistent cache
-    """
+    pass
 
 
 class StorageError(Exception):
