@@ -1,11 +1,11 @@
 import filecmp
 from pathlib import Path
-from typing import Union
+from typing import BinaryIO, Union
 
-from .compat import set_path_attrs, copy_file  # noqa
+from .compat import set_path_attrs
+from .interface import Key  # noqa
 
 PathLike = Union[Path, str]
-Key = str
 
 
 def to_read_only(path: Path, permissions, group):
@@ -35,6 +35,19 @@ def create_folders(path: Path, permissions, group):
         mkdir(path, permissions, group)
 
 
+# TODO: need functions that return bool
+
 def match_files(first: Path, second: Path):
     if not filecmp.cmp(first, second, shallow=False):
         raise ValueError(f'Files do not match: {first} vs {second}')
+
+
+def match_buffers(first: BinaryIO, second: BinaryIO, context: str):
+    bufsize = 8 * 1024
+    while True:
+        b1 = first.read(bufsize)
+        b2 = second.read(bufsize)
+        if b1 != b2:
+            raise ValueError(f'Buffers do not match: {context}')
+        if not b1:
+            return True
